@@ -23,7 +23,6 @@ import tornado.web
 
 import streamlit.server.routes
 from streamlit import type_util
-from streamlit.elements import arrow_table
 from streamlit.elements.utils import _get_widget_ui_value, NoValue
 from streamlit.errors import StreamlitAPIException
 from streamlit.logger import get_logger
@@ -109,9 +108,42 @@ class CustomComponent:
         if len(args) > 0:
             raise MarshallComponentException(f"Argument '{args[0]}' needs a label")
 
+        try:
+            import pyarrow
+            from streamlit.elements import arrow_table
+        except ImportError:
+            import sys
+
+            if sys.version_info >= (3, 9):
+                raise StreamlitAPIException(
+                    """To use Custom Components in Streamlit, you need to install
+PyArrow. Unfortunately, PyArrow does not yet support Python 3.9.
+
+You can either switch to Python 3.8 with an environment manager like PyEnv, or
+[install Streamlit with conda](https://discuss.streamlit.io/t/note-installation-issues-with-python-3-9-and-streamlit/6946/7):
+
+`conda install -c conda-forge streamlit`
+
+"""
+                )
+            else:
+                raise StreamlitAPIException(
+                    """To use Custom Components in Streamlit, you need to install
+PyArrow. To do so locally:
+
+`pip install pyarrow`
+
+And if you're using Streamlit Sharing, add "pyarrow" to your requirements.txt."""
+                )
+
+        # In addition to the custom kwargs passed to the component, we also
+        # send the special 'default' and 'key' params to the component
+        # frontend.
+        all_args = dict(kwargs, **{"default": default, "key": key})
+
         json_args = {}
         special_args = []
-        for arg_name, arg_val in kwargs.items():
+        for arg_name, arg_val in all_args.items():
             if type_util.is_bytes_like(arg_val):
                 bytes_arg = SpecialArg()
                 bytes_arg.key = arg_name
