@@ -211,16 +211,10 @@ class Server(object):
 
         return Server._singleton
 
-    def __init__(self, ioloop, script_path, command_line):
-        """Create the server. It won't be started yet.
-
-        Parameters
-        ----------
-        ioloop : tornado.ioloop.IOLoop
-        script_path : str
-        command_line : str
-
-        """
+    def __init__(
+        self, ioloop: tornado.ioloop.IOLoop, script_path: str, command_line: str
+    ):
+        """Create the server. It won't be started yet."""
         if Server._singleton is not None:
             raise RuntimeError("Server already initialized. Use .get_current() instead")
 
@@ -233,7 +227,7 @@ class Server(object):
         self._command_line = command_line
 
         # Mapping of ReportSession.id -> SessionInfo.
-        self._session_info_by_id = {}
+        self._session_info_by_id = {}  # type: Dict[str, SessionInfo]
 
         self._must_stop = threading.Event()
         self._state = None
@@ -244,6 +238,10 @@ class Server(object):
         self._report = None  # type: Optional[Report]
         self._preheated_session_id = None  # type: Optional[str]
 
+    @property
+    def script_path(self) -> str:
+        return self._script_path
+
     def on_files_updated(self, session_id):
         """Event handler for UploadedFileManager.on_file_added.
 
@@ -336,20 +334,13 @@ class Server(object):
                 dict(cache=self._message_cache),
             ),
             (
-                # Tornado doesn't allow body in DELETE requests.
-                # Passing lookup values in URL
                 make_url_path_regex(
                     base,
-                    "/upload_file/(?P<session_id>.*)/(?P<widget_id>.*)/(?P<file_id>[0-9]*)?",
+                    "/upload_file/?(?P<session_id>[^/]*)?/?(?P<widget_id>[^/]*)?/?(?P<file_id>[0-9]*)?",
                 ),
                 UploadFileRequestHandler,
                 dict(file_mgr=self._uploaded_file_mgr),
             ),
-            (
-                make_url_path_regex(base, "upload_file"),
-                UploadFileRequestHandler,
-                dict(file_mgr=self._uploaded_file_mgr),
-            ),
             (
                 make_url_path_regex(base, "assets/(.*)"),
                 AssetsFileHandler,
